pub struct LocalDataStorage<F: Format = Fixint> { /* private fields */ }Expand description
A local data storage implementation that stores data in memory.
This implementation uses local shared data storage for high-performance in-memory operations within a single node.